pub fn allocated_bytes() -> Result<usize, StateAccessError>Expand description
Returns the number of allocated bytes managed by the garbage collector.
pub fn allocated_bytes() -> Result<usize, StateAccessError>Returns the number of allocated bytes managed by the garbage collector.