pub fn buffered_objects_count() -> Result<usize, StateAccessError>Expand description
Returns the number of objects buffered to be processed in the next collection.
See Cc::mark_alive for more details.
pub fn buffered_objects_count() -> Result<usize, StateAccessError>Returns the number of objects buffered to be processed in the next collection.
See Cc::mark_alive for more details.